PaymentResult class

Constructors

PaymentResult({required PaymentResultStatus status, String? code, String? message})
PaymentResult.fromJson(Map<String, dynamic> json)
factory

Properties

code String?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PaymentResultStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited